==> haskell-postgresql-libpq-0.9.2.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-libpq
version: 0.9.2.0
id: postgresql-libpq-0.9.2.0-pfIR3xRbgN3lAiV2rvAZp
key: postgresql-libpq-0.9.2.0-pfIR3xRbgN3lAiV2rvAZp
license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
homepage: http://github.com/lpsmith/postgresql-libpq
synopsis: low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
exposed: True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal
abi: 1d02ca28ac31e94aa663bddb0c138a8b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-libpq-0.9.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-libpq-0.9.2.0
              /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.1/postgresql-libpq-0.9.2.0
hs-libraries: HSpostgresql-libpq-0.9.2.0-pfIR3xRbgN3lAiV2rvAZp
extra-libraries:
    pq
include-dirs: /usr/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock
haddock-html: /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-libpq-0.9.3.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-libpq
version: 0.9.3.0
id: postgresql-libpq-0.9.3.0-3hQCxFsBezA9tQ0YdNvQt
key: postgresql-libpq-0.9.3.0-3hQCxFsBezA9tQ0YdNvQt
license: BSD3
copyright: (c) 2010 Grant Monroe
           (c) 2011 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
homepage: http://github.com/lpsmith/postgresql-libpq
synopsis: low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.
category: Database
author: Grant Monroe, Leon P Smith, Joey Adams
exposed: True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal
abi: fb495bf19275f5a6d7ee85f30924fea3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-libpq-0.9.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/postgresql-libpq-0.9.3.0
              /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.1/postgresql-libpq-0.9.3.0
hs-libraries: HSpostgresql-libpq-0.9.3.0-3hQCxFsBezA9tQ0YdNvQt
extra-libraries:
    pq
include-dirs: /usr/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock
haddock-html: /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
